import Link from "next/link";
import React, { useEffect, useRef, useState } from "react";
import { useSellersQuery } from "../../app/features/sellers/apiSlice";
import LoadingCom from "../common/loadingCom";
import useLanguage from "../../hooks/useLanguage";

function SellerList() {
  const [page, setPage] = useState(1);
  const observerTarget = useRef(null);
  const { data: sellers, isFetching } = useSellersQuery({ page: page });

  useEffect(() => {
    const observer = new IntersectionObserver(
      (entries) => {
        if (entries[0].isIntersecting) {
          if (!isFetching && sellers?.sellers?.total > sellers?.sellers?.to) {
            setPage((prev) => prev + 1);
          }
        }
      },
      { threshold: 1 }
    );

    if (observerTarget.current) {
      observer.observe(observerTarget.current);
    }

    return () => {
      if (observerTarget.current) {
        observer.unobserve(observerTarget.current);
      }
    };
  }, [observerTarget, isFetching]);
  const language = useLanguage();
  return (
    <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 gap-7">
      {sellers?.sellers?.data?.map((item, i) => (
        <div
          key={i + "shop"}
          className="bg-white border border-primary-100 rounded-lg p-4"
          data-aos="fade-up"
          data-aos-delay={i + "00"}
        >
          <div className="w-full flex justify-center items-center h-[167px] bg-primary-200 bg-opacity-10">
            <img
              src={process.env.BASE_URL + item.logo}
              className=" max-h-32"
              alt=""
            />
          </div>
          <div className="py-5">
            <h4 className="text-2xl font-bold mb-4 notranslate">
              {item.shop_name}
            </h4>
            <p className="flex gap-2 items-center text-dark-300 mb-3 notranslate">
              <svg
                xmlns="http://www.w3.org/2000/svg"
                width="24"
                height="25"
                viewBox="0 0 24 25"
                fill="none"
              >
                <path
                  d="M6 8.28882L9.7812 10.8096C11.1248 11.7054 12.8752 11.7053 14.2188 10.8096L18 8.28882M6 21.2888H18C20.2091 21.2888 22 19.498 22 17.2888V7.28882C22 5.07968 20.2091 3.28882 18 3.28882H6C3.79086 3.28882 2 5.07968 2 7.28882V17.2888C2 19.498 3.79086 21.2888 6 21.2888Z"
                  stroke="#8037A9"
                  strokeWidth="1.5"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                />
              </svg>
              {item.email}
            </p>
            <a
              href="tel:++3353532423"
              className="flex gap-2 items-center notranslate"
            >
              <svg
                width="24"
                height="25"
                viewBox="0 0 24 25"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  d="M21 19.2888V17.6429C21 16.8251 20.5021 16.0897 19.7428 15.7859L17.7086 14.9723C16.7429 14.586 15.6422 15.0044 15.177 15.9348L15 16.2888C15 16.2888 12.5 15.7888 10.5 13.7888C8.5 11.7888 8 9.28882 8 9.28882L8.35402 9.11181C9.28438 8.64663 9.70285 7.54596 9.31654 6.58017L8.50289 4.54604C8.19916 3.78672 7.46374 3.28882 6.64593 3.28882H5C3.89543 3.28882 3 4.18425 3 5.28882C3 14.1254 10.1634 21.2888 19 21.2888C20.1046 21.2888 21 20.3934 21 19.2888Z"
                  stroke="#8037A9"
                  strokeWidth="1.5"
                  strokeLinejoin="round"
                />
              </svg>
              {item.phone}
            </a>
            {/* <span className="bg-primary-100 text-primary-200 p-2 rounded block mt-4">
            {item?.stock}
          </span> */}
          </div>
          <Link href={`suppliers/${item.slug}`} passHref>
            <a className="bg-secondary animated-btn relative text-dark-300 font-medium py-3 px-7 rounded inline-block notranslate">
              {language["View Profile"]}
            </a>
          </Link>
        </div>
      ))}
      {isFetching && (
        <div className=" col-span-1 sm:col-span-2 lg:col-span-3 xl:col-span-4 flex bg-white justify-center items-center min-h-[50vh]">
          <LoadingCom />
        </div>
      )}

      <div ref={observerTarget}></div>
    </div>
  );
}

export default SellerList;
